#!/usr/bin/env python
#  -*- coding: utf-8 -*-
# *****************************************************************************
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# Module authors:
#   Daniel Margineda <daniel.margineda@psi.ch>, Oksana Shliakhtun <oksana.shliakhtun@psi.ch>
# *****************************************************************************
"""Stanford Research SR830"""

from frappy.core import Readable, Parameter, FloatRange, TupleOf, \
    HasIO, StringIO, IntRange, BoolType, Writable, EnumType
from frappy.errors import RangeError


class XY(HasIO, Readable):
    value = Parameter('xy', TupleOf(FloatRange(unit='V'), FloatRange(unit='V')))

    class ioClass(StringIO):
        end_of_line = '\r'
        identification = [('*IDN?', r'Stanford_Research_Systems,SR830.*')]

    def read_value(self):
        return [float(v) for v in self.communicate('SNAP?1,2').split(',')]
